@@ -1,14 +1,14 @@
 import csv
 import numpy as np
 import matplotlib
-matplotlib.use('Agg')
+
+matplotlib.use("Agg")
 import matplotlib.pyplot as plt
 from matplotlib.backends.backend_pdf import PdfPages
 import pandas as pd
 
 
 class DESeqViz(object):
-    
     def __init__(self, deseq_script_path, deseq_path_template, max_pvalue):
         self._deseq_script_path = deseq_script_path
         self._deseq_path_template = deseq_path_template
@@ -31,26 +31,41 @@ class DESeqViz(object):
         self._pp_scatterplots.close()
 
     def _create_scatter_plots(self, condition_1, condition_2):
-        pd.options.display.mpl_style = 'default'
-        font = {'family': 'sans-serif', 'size': 7}
-        matplotlib.rc('font', **font)
+        matplotlib.style.use("ggplot")
+        font = {"family": "sans-serif", "size": 7}
+        matplotlib.rc("font", **font)
         deseq_result = pd.read_table(
-            self._deseq_path_template % (condition_1, condition_2))
+            self._deseq_path_template + f"{condition_1}_vs_{condition_2}.csv"
+        )
+        # Remove 0 base mean row as those would otherwise cause trouble
+        # for the log10
+        deseq_result = deseq_result[deseq_result.baseMean > 0]
         fig = plt.figure()
-        plt.plot(np.log10(deseq_result.baseMean),
-                 deseq_result.log2FoldChange, ".", alpha=0.3)
         significant_deseq_result = deseq_result[
-            deseq_result.padj < self._p_value_significance_limit]
+            (deseq_result.padj < self._p_value_significance_limit)
+        ]
+        non_significant_deseq_result = deseq_result[
+            (deseq_result.padj >= self._p_value_significance_limit)
+        ]
+        plt.plot(
+            np.log10(non_significant_deseq_result.baseMean),
+            non_significant_deseq_result.log2FoldChange,
+            ".k",
+            alpha=0.5,
+        )
         plt.plot(
             np.log10(significant_deseq_result.baseMean),
-            significant_deseq_result.log2FoldChange, ".r", alpha=0.5)
-        plt.title("{} vs. {} - MA plot".format(condition_1, condition_2))
-        y_max = max([abs(log2_fc) 
-                     for log2_fc in deseq_result.log2FoldChange])
+            significant_deseq_result.log2FoldChange,
+            ".r",
+            alpha=0.3,
+        )
+        plt.title(f"{condition_1} vs. {condition_2} - MA plot")
+        y_max = max([abs(log2_fc) for log2_fc in deseq_result.log2FoldChange])
         plt.ylim(-1.1 * y_max, 1.1 * y_max)
         plt.xlabel("log10 base mean")
         plt.ylabel("log2 fold-change")
         self._pp_scatterplots.savefig()
+        plt.close(fig)
 
     def create_volcano_plots(self, volcano_plot_path, volcano_plot_adj_path):
         self._pp_raw = PdfPages(volcano_plot_path)
@@ -71,11 +86,15 @@ class DESeqViz(object):
                     for string in ["conds <- c('", "(", ")", "'", ","]:
                         line = line.replace(string, "")
                     return sorted(list(set(line.split())))
-        
+
     def _create_volcano_plots(self, condition_1, condition_2):
-        deseq_path = self._deseq_path_template % (condition_1, condition_2)
-        (basemean, log2_fold_changes, p_values, 
-         adj_p_values) = self._parse_deseq_file(deseq_path)
+        deseq_path = self._deseq_path_template + f"{condition_1}_vs_{condition_2}.csv"
+        (
+            basemean,
+            log2_fold_changes,
+            p_values,
+            adj_p_values,
+        ) = self._parse_deseq_file(deseq_path)
         cleaned_p_values = []
         cleaned_log2_fold_changes = []
         for p_value, log2_fold_change in zip(p_values, log2_fold_changes):
@@ -83,8 +102,12 @@ class DESeqViz(object):
                 cleaned_p_values.append(p_value)
                 cleaned_log2_fold_changes.append(log2_fold_change)
         self._create_volcano_plot(
-            cleaned_log2_fold_changes, cleaned_p_values, condition_1, 
-            condition_2, self._pp_raw)
+            cleaned_log2_fold_changes,
+            cleaned_p_values,
+            condition_1,
+            condition_2,
+            self._pp_raw,
+        )
         cleaned_adj_p_values = []
         cleaned_log2_fold_changes = []
         for p_value, log2_fold_change in zip(adj_p_values, log2_fold_changes):
@@ -92,41 +115,76 @@ class DESeqViz(object):
                 cleaned_adj_p_values.append(p_value)
                 cleaned_log2_fold_changes.append(log2_fold_change)
         self._create_volcano_plot(
-            cleaned_log2_fold_changes, cleaned_adj_p_values, 
-            condition_1, condition_2, self._pp_adj, 
-            pvalue_string_mod="(adjusted)")
+            cleaned_log2_fold_changes,
+            cleaned_adj_p_values,
+            condition_1,
+            condition_2,
+            self._pp_adj,
+            pvalue_string_mod="(adjusted)",
+        )
 
     def _create_volcano_plot(
-        self, log2_fold_changes, p_values, condition_1, condition_2, pp,
-        pvalue_string_mod=""):
+        self,
+        log2_fold_changes,
+        p_values,
+        condition_1,
+        condition_2,
+        pp,
+        pvalue_string_mod="",
+    ):
         fig = plt.figure()
         max_log_2_fold_change = max(
-            [abs(min(log2_fold_changes)), 
-             abs(max(log2_fold_changes))])
+            [abs(min(log2_fold_changes)), abs(max(log2_fold_changes))]
+        )
+        # To avoid problem with zero in log10
+        p_values = np.array(p_values)
+        p_values[p_values == 0.0] = 10**-100
         mod_p_values = -1 * np.log10(p_values)
+        mod_p_values[mod_p_values == float("+inf")] = 0.0
+        mod_p_values[mod_p_values == float("-inf")] = 0.0
         max_mod_p_values = max(mod_p_values)
         # Set axis ranges
-        plt.axis([-1*max_log_2_fold_change, max_log_2_fold_change, 
-                   0, max_mod_p_values])
+        plt.axis(
+            [
+                -1 * max_log_2_fold_change,
+                max_log_2_fold_change,
+                0,
+                max_mod_p_values,
+            ]
+        )
         plt.plot(log2_fold_changes, mod_p_values, "k.", alpha=0.3)
         # Add axis labels
         plt.xlabel("log$_2$ fold change")
-        plt.ylabel("- log$_{10}$ p-value %s" % (pvalue_string_mod))
-        plt.title("%s vs. %s" % (condition_1, condition_2))
-        signifant_p_value = -1*np.log10(self._p_value_significance_limit)
-        plt.plot([-1*max_log_2_fold_change, max_log_2_fold_change], 
-                 [signifant_p_value, signifant_p_value], 
-                 linestyle="dotted", color="green", alpha=0.5)
-        log2_fold_change_limit = 1
-        plt.plot([-1*self._log_2_fold_chance_limit, 
-                   -1*self._log_2_fold_chance_limit],
-                 [0, max_mod_p_values], 
-                 linestyle="dotted", color="green", alpha=0.5)
-        plt.plot([self._log_2_fold_chance_limit, 
-                  self._log_2_fold_chance_limit], 
-                 [0, max_mod_p_values], 
-                 linestyle="dotted", color="green", alpha=0.5)
+        plt.ylabel(f"- log$_{10}$ p-value {pvalue_string_mod}")
+        plt.title(f"{condition_1} vs. {condition_2}")
+        significant_p_value = -1 * np.log10(self._p_value_significance_limit)
+        plt.plot(
+            [-1 * max_log_2_fold_change, max_log_2_fold_change],
+            [significant_p_value, significant_p_value],
+            linestyle="dotted",
+            color="green",
+            alpha=0.5,
+        )
+        # log2_fold_change_limit = 1 (never used)
+        plt.plot(
+            [
+                -1 * self._log_2_fold_chance_limit,
+                -1 * self._log_2_fold_chance_limit,
+            ],
+            [0, max_mod_p_values],
+            linestyle="dotted",
+            color="green",
+            alpha=0.5,
+        )
+        plt.plot(
+            [self._log_2_fold_chance_limit, self._log_2_fold_chance_limit],
+            [0, max_mod_p_values],
+            linestyle="dotted",
+            color="green",
+            alpha=0.5,
+        )
         pp.savefig()
+        plt.close(fig)
 
     def _parse_deseq_file(self, deseq_path):
         basemeans = []
@@ -138,9 +196,10 @@ class DESeqViz(object):
                 continue
             basemeans.append(float(row[self._basemean_column]))
             for value_list, column_no in (
-                    (log_2_fold_changes, self._log_2_fold_chance_column),
-                    (p_values, self._p_value_column),
-                    (adj_p_values, self._adj_p_value_column)):
+                (log_2_fold_changes, self._log_2_fold_chance_column),
+                (p_values, self._p_value_column),
+                (adj_p_values, self._adj_p_value_column),
+            ):
                 try:
                     value_list.append(float(row[column_no]))
                 except ValueError:
